/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package hero.main;

import java.io.InputStream;
import java.util.Collection;

import javax.security.auth.login.LoginContext;

import org.ow2.bonita.facade.UserBean;
import org.ow2.bonita.facade.UserInterface;

/**
 * @author "Pierre Vigneras", "Marc Blachon"
 */
public class ApprovalWorkflowClientForJavaLib {
	private static final String PROCESS_NAME = "BonitaSimpleProjectEver";

	public static void main(String[] args) throws Exception {
		if (args.length != 1) {
			System.err.println("Usage: " + ApprovalWorkflowClientForJavaLib.class + " XPDLFileName");
			System.exit(1);
		}
		
		final LoginContext loginContext = new LoginContext("Bonita", new StandardCallbackHandler());
		loginContext.login();

		final InputStream in = ApprovalWorkflowClientForJavaLib.class.getResourceAsStream(args[0]);
		if (in == null) throw new Exception("Can't find ressource: " + args[0]);
		XpdlImporter.importFrom(in);
		final UserInterface user = new UserBean();
		final String instanceName = user.instanciateProcess(PROCESS_NAME);
		final Collection<String> tasks = user.getToDoList(instanceName);
		if (tasks.isEmpty()) System.out.println("No task found? Bad User?");
		for (String task : tasks) {
			user.startActivity(instanceName, task);
			System.out.println("Starting task: " + task);
			user.terminateActivity(instanceName, task);
			System.out.println("Task " + task + " terminated.");
		}
		loginContext.logout();
	}
}
