/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package hero.main;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.util.Collection;
import java.util.Hashtable;

import javax.naming.Context;
import javax.naming.InitialContext;
import javax.naming.NamingException;

import org.ow2.bonita.deployment.XpdlParserException;
import org.ow2.bonita.facade.UserInterface;
import org.ow2.bonita.facade.XPDLImportInterface;
import org.ow2.bonita.util.BonitaException;


/**
 * @author "Pierre Vigneras", "Marc Blachon"
 */
public class ApprovalWorkflowClientForStateless {
	//private static final String XPDL_FILE = "/home/blachonm/workspace/bonitaPVM/target/bonita-4.0.M1/examples/BonitaSimpleProjectEver/BonitaSimpleProjectEverStateless_1.0.xpdl";
	private static final String RESSOURCE = "BonitaSimpleProjectEverStateless_1.0.xpdl";
	private static final String PROCESS_NAME = "BonitaSimpleProjectEverStateless";
    /**
     * Default InitialContextFactory to use.
     */
    private static final String DEFAULT_INITIAL_CONTEXT_FACTORY = "org.objectweb.carol.jndi.spi.MultiOrbInitialContextFactory";

    /**
     * JNDI name of the XPDLImportBean.
     */
     private static final String JNDI_NAME_XPDLImport =
          "org.ow2.bonita.facade.XPDLImportBean"
          + "_" + XPDLImportInterface.class.getName() + "@Remote";
     /**
      * JNDI name of the UserBean.
      */
      private static final String JNDI_NAME_User =
           "org.ow2.bonita.facade.UserBean"
           + "_" + UserInterface.class.getName() + "@Remote";

	/**
	 * @param args
	 */
	public static void main(String[] args) {
	    Context initialContext = null;
	    XPDLImportInterface xpdlImport = null;
	    UserInterface user = null;

		    Hashtable<String, Object> env = new Hashtable<String, Object>();
	        env.put(Context.INITIAL_CONTEXT_FACTORY, "org.ow2.easybeans.component.smartclient.spi.SmartContextFactory");
	        try {
                initialContext =  new InitialContext(env);
            } catch (NamingException e1) {
                e1.printStackTrace();
                System.exit(-1);
            }

            //get the business interface for XPDLImport
            try {
                xpdlImport = (XPDLImportInterface) initialContext.lookup(JNDI_NAME_XPDLImport);
            } catch (NamingException e1) {
                e1.printStackTrace();
                System.exit(-1);
            }

            /*
             *   get the xpdl_file string
             */
            BufferedReader buff = null;
            InputStream in = ApprovalWorkflowClientForStateless.class.getResourceAsStream(RESSOURCE);
            InputStreamReader inr = new InputStreamReader(in);
            buff = new java.io.BufferedReader(inr);
            String line, xpdl_file = "";
	        try {
	            line = buff.readLine();
	            while ((line = buff.readLine()) != null)
	                xpdl_file = xpdl_file + line;
	        } catch (IOException e) {
	            System.err.println("Exception while reading lines : "
	                    + e.getMessage());
	            e.printStackTrace();
	            System.exit(-1);
	        }


	        System.out.println("Calling XPDLImport method...");
	        try {
	         //call the remote business method
	         xpdlImport.importDocument(xpdl_file);
        		} catch (XpdlParserException e) {
        			System.err.println("Ouch! Bad XPDL file? File is: " + RESSOURCE);
        			e.printStackTrace();
        			System.exit(1);
        		}

        		//get the business UserSession interface
            try {
                user = (UserInterface) initialContext.lookup(JNDI_NAME_User);
            } catch (NamingException e1) {
                e1.printStackTrace();
                System.exit(-1);
            }
            try{
                String instanceName = user.instanciateProcess(PROCESS_NAME);

			Collection<String> tasks =  user.getToDoList(instanceName);
			for (String task : tasks){
				System.out.println("Starting task: " + task);
				user.startActivity(instanceName, task);
				user.terminateActivity(instanceName, task);
				System.out.println("Task " + task + " terminated.");
			}

        		}catch(BonitaException be) {
        			be.printStackTrace();
        		}
	}
}
