/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package hero.main.standard;

import hero.main.XpdlImporter;
import hero.main.StandardCallbackHandler;
import java.io.InputStream;
import java.util.Collection;
import java.util.logging.LogManager;

import javax.security.auth.login.LoginContext;

import org.ow2.bonita.facade.UserBean;
import org.ow2.bonita.facade.UserInterface;
import org.ow2.bonita.tests.XpdlTestCase;

/**
 * @author "Pierre Vigneras", "Marc Blachon"
 */
public class ApprovalWorkflow {
	private static final String PROCESS_NAME = "BonitaSimpleProjectEver";

	private static class SimpleCallbackHandler implements javax.security.auth.callback.CallbackHandler {
	    private final String username;
	    private final char[] password;

	    public SimpleCallbackHandler(final String username, final char[] password) {
	        this.username = username;
	        this.password = password;
	    }

	    public void handle(javax.security.auth.callback.Callback[] callbacks) throws java.io.IOException, javax.security.auth.callback.UnsupportedCallbackException {
	        for (int i = 0; i < callbacks.length; i++) {
	                if (callbacks[i] instanceof javax.security.auth.callback.NameCallback) {
	                	javax.security.auth.callback.NameCallback nc = (javax.security.auth.callback.NameCallback)callbacks[i];
	                        nc.setName(username);
	                    }else if (callbacks[i] instanceof javax.security.auth.callback.PasswordCallback) {
	                    	javax.security.auth.callback.PasswordCallback pc = (javax.security.auth.callback.PasswordCallback)callbacks[i];
	                        pc.setPassword(password);
	                    }else {
	                        throw new javax.security.auth.callback.UnsupportedCallbackException(callbacks[i], "Unrecognized Callback");
	                    }
	            }
	    }
	}

	public static void main(String[] args) throws Exception {
		if (args.length != 1) {
			System.err.println("Usage: " + ApprovalWorkflow.class + " XPDLFileName");
			System.exit(1);
		}
		
        try {
            InputStream inputStream = ApprovalWorkflow.class.getClassLoader().getResourceAsStream("logging.properties");
            if (inputStream != null) {
              LogManager.getLogManager().readConfiguration(inputStream);
            }
          } catch (Exception e) {
            throw new RuntimeException("couldn't initialize logging properly", e);
          }		
		
		final LoginContext loginContext = new LoginContext("Bonita", new StandardCallbackHandler());
        //final LoginContext loginContext = new LoginContext("Bonita", new SimpleCallbackHandler("John", "cheese".toCharArray()));  
		loginContext.login();

		final InputStream in = ApprovalWorkflow.class.getResourceAsStream(args[0]);
		if (in == null) throw new Exception("Can't find ressource: " + args[0]);
		XpdlImporter.importFrom(in);
		final UserInterface user = new UserBean();
		final String instanceName = user.instanciateProcess(PROCESS_NAME);
		final Collection<String> tasks = user.getToDoList(instanceName);
		if (tasks.isEmpty()) System.out.println("No task found? Bad User?");
		for (String task : tasks) {
			user.startActivity(instanceName, task);
			System.out.println("Starting task: " + task);
			user.terminateActivity(instanceName, task);
			System.out.println("Task " + task + " terminated.");
		}
		loginContext.logout();
	}
}
